@@ -6,6 +6,7 @@ import secrets
 import sys
 from types import ModuleType
 from typing import Any
+from typing import Callable
 from typing import Dict
 from typing import Iterator
 from typing import List
@@ -60,6 +61,7 @@ class Hub:
         if HAS_TESTING_LIBS:
             pypaths.append("pytest_pop.mods")
         self._subs["pop"] = Sub(self, "pop", pypath=pypaths)
+        self._reverse_sub = None
         self._iter_subs = sorted(self._subs.keys())
         self._iter_ind = 0
         # Set up the conf OPT structure so it is always available
@@ -153,7 +155,7 @@ class Sub:
         self,
         hub: Hub,
         subname: str,
-        root: Hub or Sub = None,
+        root: Hub or "Sub" = None,
         pypath: List[str] or str = None,
         static: List[str] or str = None,
         contracts_pypath: List[str] or str = None,
@@ -216,6 +218,7 @@ class Sub:
             default_contracts = [default_contracts]
         if isinstance(default_recursive_contracts, str):
             default_recursive_contracts = [default_recursive_contracts]
+        self._reverse_sub = None
         self._default_recursive_contracts = default_recursive_contracts or []
         self._default_contracts = default_contracts or ()
         self._dyne_name = dyne_name
@@ -260,8 +263,8 @@ class Sub:
 
         if self._contract_dirs:
             self._contracts = Sub(
-                self._hub,
-                f"{self._subname}.contracts",
+                hub=self._hub,
+                subname=f"{self._subname}.contracts",
                 static=self._contract_dirs,
                 is_contract=True,
             )
@@ -270,8 +273,8 @@ class Sub:
 
         if self._recursive_contract_dirs:
             self._recursive_contracts = Sub(
-                self._hub,
-                f"{self._subname}.recursive_contracts",
+                hub=self._hub,
+                subname=f"{self._subname}.recursive_contracts",
                 static=self._recursive_contract_dirs,
                 is_contract=True,
             )
@@ -333,9 +336,10 @@ class Sub:
         """
         if item.startswith("_"):
             return self.__getattribute__(item)
-        if "." in item:
-            return self._hub.pop.ref.last(f"{self._subname}.{item}")
-        if item in self._loaded:
+        elif "." in item:
+            # Get the attribute from one sub higher up until the hub calls "ref.last"
+            return getattr(self._root, f"{self._subname}.{item}")
+        elif item in self._loaded:
             ret = self._loaded[item]
             # If this previously errored on load, try it again,
             # it might be ready to load now
@@ -354,6 +358,9 @@ class Sub:
 
         mod = self._find_mod(item)
         if mod is None:
+            if self._reverse_sub:
+                # This sub contains a reverse sub that could contain the result
+                return self._reverse_sub[item]
             raise AttributeError(f"'{self._subname}' has no attribute '{item}'")
         return mod
 
@@ -362,18 +369,21 @@ class Sub:
 
     def __contains__(self, item: str):
         try:
-            return hasattr(self, item)
+            ret = getattr(self, item, None)
+            if isinstance(ret, ReverseSub):
+                return item in self._reverse_sub
+            return ret is not None
         except pop.exc.PopLookupError:
             return False
 
     def __iter__(self) -> Iterator["Sub"]:
         self._load_all()
 
-        def iter(loaded):
-            for l in sorted(loaded.keys()):
-                yield loaded[l]
+        def iterate(loaded):
+            for mod_name in sorted(loaded.keys()):
+                yield loaded[mod_name]
 
-        return iter(self._loaded)
+        return iterate(self._loaded)
 
     def __next__(self) -> "Sub":
         self._load_all()
@@ -552,3 +562,127 @@ class Sub:
                     continue
                 self._load_item(iface, bname)
         self._loaded_all = True
+
+
+class ReverseSub(Sub):
+    """
+    A sub that discovers attributes available to it dynamically through a resolver
+    """
+
+    def __init__(
+        self,
+        hub: Hub,
+        subname: str,
+        resolver: Callable,
+        context: Any = None,
+        refs: Tuple[str, ...] = None,
+        **kwargs,
+    ):
+        """
+        :param subname: The name that the sub is going to take on the hub
+        :param resolver: A callable function that retrieves a target based on the current reference and context
+        :param context: Resources that will be passed to the resolver function
+        :param kwargs: Any kwargs that should be passed to the underlying sub
+        """
+        Sub.__init__(self, subname=subname, hub=hub, **kwargs)
+        self._resolver = resolver
+        self._context = context
+        # self._loaded_all = True
+        if refs is None:
+            self._refs = tuple([*subname.split(".")])
+        else:
+            self._refs = tuple([*refs, *subname.split(".")])
+
+        # Imitate the name attribute like a callable should
+        self.__name__ = self._subname
+
+    def __getattr__(self, item: str):
+        """
+        Build a reference based on the namespace attrs until a reverse sub is called
+        """
+        if item.startswith("_"):
+            return self.__getattribute__(item)
+
+        return ReverseSub(
+            hub=self._hub,
+            subname=item,
+            # Share a root
+            root=self._root,
+            resolver=self._resolver,
+            context=self._context,
+            pypath=self._pypath,
+            refs=self._refs,
+            static=self._static,
+            contracts_pypath=self._contracts_pypath,
+            contracts_static=self._recursive_contracts_static,
+            default_contracts=self._default_contracts,
+            virtual=self._virtual,
+            dyne_name=self._dyne_name,
+            omit_start=self._omit_start,
+            omit_end=self._omit_end,
+            omit_func=self._omit_func,
+            omit_class=self._omit_class,
+            omit_vars=self._omit_vars,
+            mod_basename=self._mod_basename,
+            stop_on_failures=self._stop_on_failures,
+            init=None,
+            is_contract=self._is_contract,
+            sub_virtual=self._sub_virtual,
+            recursive_contracts_static=self._recursive_contracts_static,
+            default_recursive_contracts=self._default_recursive_contracts,
+        )
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        # Override the parent Sub's iterator
+        raise StopIteration
+
+    def __contains__(self, item):
+        """
+        Return true if the item's reference underneath this one is resolvable
+        """
+        try:
+            if getattr(self, item)._resolve():
+                return True
+        except Exception:
+            ...
+        return False
+
+    def _resolve(self) -> Callable or None:
+        """
+        Call the resolver and get back the external call represented by this sub's reference
+        """
+        ref = ".".join(self._refs)
+        ret = self._resolver(ref, self._context)
+        return ret
+
+    def __call__(self, *args, **kwargs):
+        func = self._resolve()
+
+        if not func:
+            ref = ".".join(self._refs)
+            raise AttributeError(f"ReverseSub could not resolve the reference {ref}")
+        if isinstance(func, pop.contract.Contracted):
+            discovered_contracted_function = func
+        else:
+            discovered_contracted_function = pop.contract.create_contracted(
+                hub=self._hub,
+                contracts=getattr(self._contracts, "_loaded", {}).values(),
+                func=func,
+                ref=".".join(self._refs),
+                name=func.__name__,
+                implicit_hub=False,
+            )
+
+        if self._recursive_contracts and not all(
+            rc in discovered_contracted_function.contracts
+            for rc in self._recursive_contracts
+        ):
+            discovered_contracted_function.contracts.extend(
+                self._recursive_contracts._loaded.values()
+            )
+            discovered_contracted_function._load_contracts()
+
+        return discovered_contracted_function(*args, **kwargs)
