@@ -64,8 +64,8 @@ class LoadError(Exception):
 def load_mod(modname: str, form: str, path: str) -> "LoadedMod":
     """
     Load a single module
-    :param form: The name of the loader module
     :param modname: The name of the module to get from the loader
+    :param form: The name of the loader module
     :param path: The package to use as the anchor point from which to resolve the
         relative import to an absolute import.
     """
@@ -91,7 +91,7 @@ def _generate_module(name: str) -> types.ModuleType:
     return module
 
 
-def _populate_sys_modules(mod: "LoadedMod"):
+def _populate_sys_modules(mod: str):
     """
     This is a hack to populate sys.modules with the modules that pop loads
     while making sure that parent modules have the attribute for the child
