@@ -1,12 +1,11 @@
 """
 Convenience wrappers to make using the conf system as easy and seamless as possible
 """
+import warnings
 from typing import Any
 from typing import Dict
 from typing import List
 
-import pop.hub
-
 
 def integrate(
     hub: "pop.hub.Hub",
@@ -20,7 +19,8 @@ def integrate(
     """
     Load the conf sub and run the integrate sequence.
     """
-    hub.pop.sub.add("pop.mods.conf")
+    warnings.warn("Use `hub.pop.config.load()` instead", DeprecationWarning)
+    hub.pop.sub.add("pop_conf.conf")
     hub.conf.integrate.load(
         imports, override, cli=cli, roots=roots, loader=loader, logs=logs
     )
