@@ -1,7 +1,11 @@
 """
 Tools to work with dicts
 """
-import pop.dicts
+import warnings
+
+import dict_tools.data
+import dict_tools.update
+
 import pop.hub
 
 
@@ -16,7 +20,10 @@ def traverse(hub: "pop.hub.Hub", data, key, default=None, delimiter=":"):
     {'foo':{'bar':['baz']}} , if data like {'foo':{'bar':{'0':'baz'}}}
     then return data['foo']['bar']['0']
     """
-    return pop.dicts.traverse(data, key, default.delimiter)
+    warnings.warn(
+        "Use `dict_tools.data.traverse_dict_and_list()` instead", DeprecationWarning
+    )
+    return dict_tools.data.traverse_dict_and_list(data, key, default.delimiter)
 
 
 def update(hub: "pop.hub.Hub", dest, upd, recursive_update=True, merge_lists=True):
@@ -25,12 +32,15 @@ def update(hub: "pop.hub.Hub", dest, upd, recursive_update=True, merge_lists=Tru
 
     Merges upd recursively into dest
 
-    If recursive_update=False, will use the classic dict.update, or fall back
-    on a manual merge (helpful for non-dict types like FunctionWrapper)
+    If recursive_update=false, will use the classic dict.update, or fall back
+    on a manual merge (helpful for non-dict types like functionwrapper)
 
-    If merge_lists=True, will aggregate list object types instead of replace.
-    The list in ``upd`` is added to the list in ``dest``, so the resulting list
+    If merge_lists=true, will aggregate list object types instead of replace.
+    the list in ``upd`` is added to the list in ``dest``, so the resulting list
     is ``dest[key] + upd[key]``. This behavior is only activated when
     recursive_update=True. By default merge_lists=False.
     """
-    return pop.dicts.update(dest, upd, recursive_update, merge_lists)
+    warnings.warn(
+        "Use `dict_tools.update.update()` instead", DeprecationWarning, stacklevel=1
+    )
+    return dict_tools.update.update(dest, upd, recursive_update, merge_lists)
