@@ -3,6 +3,7 @@ Control and add subsystems to the running daemon hub
 """
 import os
 from collections.abc import Mapping
+from typing import Any
 from typing import Callable
 from typing import Dict
 from typing import Generator
@@ -179,6 +180,8 @@ def load_subdirs(hub: pop.hub.Hub, sub: pop.hub.Sub, recurse: bool = False):
                 continue
             if fn == "contracts":
                 continue
+            if fn == "recursive_contracts":
+                continue
             full = os.path.join(dir_, fn)
             if not os.path.isdir(full):
                 continue
@@ -258,105 +261,43 @@ def extend(
     return True
 
 
-def dynamic(hub: pop.hub.Hub, sub: pop.hub.Sub, get_reference: Callable):
+def dynamic(
+    hub: pop.hub.Hub,
+    resolver: Callable,
+    context: Any = None,
+    **kwargs,
+):
     """
-    Create dynamic subs underneath the named sub.
-    When a dynamic sub is called, determine the actual path that should be used
-    and call the reference with the parameters passed to the Dynamic Sub
+    Create dynamic (reverse) subs underneath the named sub.
+    When a ReverseSub is called, it resolves it's current reference and calls the appropriate external function
+    based on the current reference and context (as determined by the resolver).
 
     :param hub: The redistributed pop central hub
-    :param sub: The sub to modify to have dynamic subs underneath it
-    :param get_reference: A callable function that returns the desired target base sub
+    :param resolver: A callable function that retrieves a target based on the current reference and context
+    :param context: Resources that will be passed to the resolver function
+    :param kwargs: kwargs to pass directly to hub.pop.sub.add
     """
+    subname = kwargs.pop("subname", None)
+    if "pypath" in kwargs and not subname:
+        pypath = pop.hub.ex_path(kwargs["pypath"])
+        subname = pypath[0].split(".")[-1]
+    elif "static" in kwargs:
+        subname = os.path.basename(kwargs["static"])
+    if "dyne_name" in kwargs and not subname:
+        subname = kwargs["dyne_name"]
 
-    class Dynamic(Mapping):
-        def __init__(
-            self,
-            parent_sub: pop.hub.Sub,
-            subs: Dict[str, pop.hub.Sub],
-            ref: str = "",
-        ):
-            """
-            :param parent_sub: The sub that owns the Dynamic subs
-            :param subs: The subs that belonged to the parent sub
-            :param ref: The names of Dynamic subs that led up to this reference
-            """
-            self._sub = parent_sub
-            self._subs = subs
-            self._ref = ref
+    root = kwargs.pop("sub", hub)
 
-        def __getitem__(self, name: str) -> pop.hub.Sub:
-            """
-            If the sub exists in the parent sub dictionary, return it directly.
-            If the sub does not exist in the parent, then create a CallableSub
-            that can be used to call the desired function when the ref has been fully built.
-            :param name: The name of the sub to return
-            """
-            # Return the sub if it exists, this is a static reference
-            if name in self._subs:
-                return self._subs[name]
-            else:
-                # Check if one of our static subs has the name we are looking for
-                for static_sub in self._subs.values():
-                    if name in static_sub._alias:
-                        return static_sub
+    if subname not in root._subs:
+        # Only add reverse subs on top of conventional subs
+        hub.pop.sub.add(sub=root, subname=subname, **kwargs)
 
-            # We are working with an unresolved reference
-
-            # Keep track of the dynamic reference chain that has led up to the current dynamic sub
-            if self._ref:
-                ref = f"{self._ref}.{name}"
-            else:
-                ref = name
-
-            # In case the unresolved reference happens to be a function, create a callable sub
-            callable_sub = CallableSub(
-                hub=hub, subname=name, root=self._sub, init=False, ref=ref
-            )
-
-            # Any subsequent references are just as unresolved as this one, replace subs with Dynamic subs
-            callable_sub._subs = Dynamic(callable_sub, {}, ref)
-            return callable_sub
-
-        # These methods maintain the functionality of being a mapping of sub-names to subs
-        def __setitem__(self, name: str, new_sub: pop.hub.Sub):
-            self._subs[name] = new_sub
-
-        def __len__(self) -> int:
-            return len(self._subs)
-
-        def __iter__(self) -> Iterator[str]:
-            return iter(self._subs)
-
-    class CallableSub(pop.hub.Sub):
-        """
-        A Sub that transforms a Dynamic reference on the hub to a static reference and calls it.
-        """
-
-        def __init__(self, ref: str, *args, **kwargs):
-            self._ref = ref
-            super().__init__(*args, **kwargs)
-
-        def __call__(self, *args, **kwargs):
-            # Get the actual base reference based on user logic
-            func = get_reference(*args, **kwargs)
-            # Transform the built reference determined by parent dynamic subs into a real function located on the hub
-            for ref in self._ref.split("."):
-                func = getattr(func, ref)
-
-            if isinstance(func, CallableSub):
-                # If the reference didn't resolve, we need to preventan infinite recursion error
-                full_ref = sub._subname
-                sub_root = sub._root
-                while isinstance(sub_root, pop.hub.Sub):
-                    full_ref = f"{sub_root._subname}.{full_ref}"
-                    sub_root = sub_root._root
-                raise ModuleNotFoundError(
-                    f"Reference does not exist {full_ref}.{self._ref}"
-                )
-
-            # Call the target function with the parameters passed to the callable sub
-            return func(*args, **kwargs)
-
-    # replace the _subs dict with a dynamically referenced version
-    sub._subs = Dynamic(sub, sub._subs)
+    root._subs[subname]._reverse_sub = pop.hub.ReverseSub(
+        hub=hub,
+        resolver=resolver,
+        context=context,
+        subname=subname,
+        root=root._subs[subname],
+        sub_virtual=getattr(root._subs[subname], "_subvirt", True),
+        **kwargs,
+    )
