@@ -1,11 +1,13 @@
-# Import python libs
 import inspect
+from typing import Any
+from typing import Callable
+from typing import Dict
+from typing import Iterable
+from typing import List
 
-# Import pop libs
 import pop.exc
 import pop.hub
 import pop.loader
-from typing import Any, Callable, Dict, Iterable, List
 
 
 def contract(
